@@ -106,6 +106,10 @@ static GHashTable *shapelist_table = NULL;
 static gint SHAPE_BOX_WIDTH_RATIO = 18;
 
 static GooCanvasItem	*shape_root_item;
+static GooCanvasItem	*title_root_item;
+/* info is like title but only displayed when the puzzle
+   is completed */
+static GooCanvasItem	*info_root_item;
 static GooCanvasItem	*shape_list_root_item;
 
 /* The tooltip */
@@ -141,7 +145,8 @@ static Shape 		*create_shape(ShapeType type, char *name, char *tooltip,
 				      double w, double h, double zoomx,
 				      double zoomy, guint position, char *soundfile);
 static gboolean 	 increment_sublevel(void);
-static void 		 create_title(char *name, double x, double y,
+static void 		 create_title(GooCanvasItem *parent,
+				      char *name, double x, double y,
 				      GtkAnchorType anchor,
 				      guint32 color_rgba,
 				      gchar *color_background);
@@ -503,6 +508,8 @@ static void shapegame_destroy_all_items()
 
       goo_canvas_item_remove(shape_root_item);
       shape_root_item = NULL;
+      title_root_item = NULL;
+      info_root_item = NULL;
 
       goo_canvas_item_remove(tooltip_root_item);
       tooltip_root_item = NULL;
@@ -528,10 +535,15 @@ static void shapegame_init_canvas(GooCanvasItem *parent)
 			    BOARDWIDTH/SHAPE_BOX_WIDTH_RATIO,
 			    0);
 
+  title_root_item = goo_canvas_group_new (shape_root_item, NULL);
+  info_root_item = goo_canvas_group_new (shape_root_item, NULL);
+  g_object_set (info_root_item, "visibility",
+		GOO_CANVAS_ITEM_INVISIBLE, NULL);
+
   shape_list_root_item = goo_canvas_group_new (parent, NULL);
 
   /* Create the tooltip area */
-  tooltip_root_item = goo_canvas_group_new (goo_canvas_get_root_item(gcomprisBoard->canvas),
+  tooltip_root_item = goo_canvas_group_new (parent,
 					    NULL);
   goo_canvas_item_translate(tooltip_root_item, 10, BOARDHEIGHT-70);
 
@@ -583,6 +595,16 @@ static void shapegame_init_canvas(GooCanvasItem *parent)
 		   (GtkSignalFunc) item_event_ok,
 		   "continue_click");
 
+  g_signal_connect(continue_root_item,
+		   "enter_notify_event",
+		   (GtkSignalFunc) item_event_ok,
+		   "title_raise");
+
+  g_signal_connect(continue_root_item,
+		   "leave_notify_event",
+		   (GtkSignalFunc) item_event_ok,
+		   "title_lower");
+
   /* Hide the continue */
   g_object_set (continue_root_item, "visibility", GOO_CANVAS_ITEM_INVISIBLE, NULL);
 
@@ -917,7 +939,7 @@ item_event_drag(GooCanvasItem *item,
 	{
 	case SHAPE_TARGET:
 	  /* unplace this shape */
-	  if (shape->placed)
+	  if (shape->placed && shape->placed->target_point)
 	    g_object_set (shape->placed->target_point, "visibility",
 			  GOO_CANVAS_ITEM_VISIBLE, NULL);
 	  shape->placed->shape_place = NULL;
@@ -1050,11 +1072,15 @@ item_event_drag(GooCanvasItem *item,
 				+ BOARDWIDTH/SHAPE_BOX_WIDTH_RATIO,
 				found_shape->y - (bounds.y2 - bounds.y1) / 2);
 
-	  g_object_set (found_shape->target_point, "visibility",
-			GOO_CANVAS_ITEM_INVISIBLE, NULL);
-	  g_object_set (target_item, "visibility",
-			GOO_CANVAS_ITEM_VISIBLE, NULL);
-	  goo_canvas_item_raise(target_item, NULL);
+	  if(found_shape->target_point)
+	    g_object_set (found_shape->target_point, "visibility",
+			  GOO_CANVAS_ITEM_INVISIBLE, NULL);
+	  if(target_item)
+	    {
+	      g_object_set (target_item, "visibility",
+			    GOO_CANVAS_ITEM_VISIBLE, NULL);
+	      goo_canvas_item_raise(target_item, NULL);
+	    }
 
 	  if(shape->type == SHAPE_ICON)
 	    g_object_set (shape->item, "visibility",
@@ -1246,6 +1272,25 @@ item_event_ok(GooCanvasItem *item, GooCanvasItem *target,
 
       root_item = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
       g_object_set (root_item, "visibility", GOO_CANVAS_ITEM_VISIBLE, NULL);
+      break;
+
+    case GDK_ENTER_NOTIFY:
+      if(!strcmp(data, "title_raise"))
+	{
+	  goo_canvas_item_raise(title_root_item, NULL);
+	  g_object_set (info_root_item, "visibility",
+			GOO_CANVAS_ITEM_VISIBLE, NULL);
+	  goo_canvas_item_raise(info_root_item, NULL);
+	  gc_bar_hide(TRUE);
+	}
+    case GDK_LEAVE_NOTIFY:
+      if(!strcmp(data, "title_lower"))
+	{
+	  goo_canvas_item_lower(title_root_item, NULL);
+	  g_object_set (info_root_item, "visibility",
+			GOO_CANVAS_ITEM_INVISIBLE, NULL);
+	  gc_bar_hide(FALSE);
+	}
 
     default:
       break;
@@ -1290,22 +1335,26 @@ add_shape_to_canvas(Shape *shape)
     {
       if(shape->targetfile)
 	{
-	  targetpixmap = gc_pixmap_load(shape->targetfile);
-	  shape->w = (double)gdk_pixbuf_get_width(targetpixmap);
-	  shape->h = (double)gdk_pixbuf_get_height(targetpixmap);
+	  if(shape->targetfile[0] != '\0')
+	    {
+	      targetpixmap = gc_pixmap_load(shape->targetfile);
+	      shape->w = (double)gdk_pixbuf_get_width(targetpixmap);
+	      shape->h = (double)gdk_pixbuf_get_height(targetpixmap);
 
-	  item = goo_canvas_image_new (shape_root_item,
-				       targetpixmap,
-				       0, 0,
-				       NULL);
-	  goo_canvas_item_translate(item,
-				    shape->x - shape->w / 2,
-				    shape->y - shape->h / 2);
-	  goo_canvas_item_scale(item,
-				shape->zoomx, shape->zoomy);
+	      item = goo_canvas_image_new (shape_root_item,
+					   targetpixmap,
+					   0, 0,
+					   NULL);
+	      goo_canvas_item_translate(item,
+					shape->x - shape->w / 2,
+					shape->y - shape->h / 2);
+	      goo_canvas_item_scale(item,
+				    shape->zoomx, shape->zoomy);
 
-	  shape->targetitem = item;
-	  gdk_pixbuf_unref(targetpixmap);
+	      shape->targetitem = item;
+	      gdk_pixbuf_unref(targetpixmap);
+	    }
+	  // An empty targetfile means no target and no point
 	}
       else
 	{
@@ -1322,7 +1371,8 @@ add_shape_to_canvas(Shape *shape)
 					 NULL);
 	  shape->target_point = item;
 	}
-      goo_canvas_item_lower(item, NULL);
+      if (item)
+	goo_canvas_item_lower(item, NULL);
     }
 
   if(shape->pixmapfile)
@@ -1367,7 +1417,8 @@ add_shape_to_canvas(Shape *shape)
 }
 
 static void
-create_title(char *name, double x, double y,
+create_title(GooCanvasItem *parent,
+	     char *name, double x, double y,
 	     GtkAnchorType anchor,
 	     guint32 color_rgba,
 	     gchar *color_background)
@@ -1375,7 +1426,7 @@ create_title(char *name, double x, double y,
   GooCanvasItem *item;
 
   item = \
-    goo_canvas_text_new (shape_root_item,
+    goo_canvas_text_new (parent,
 			 gettext(name),
 			 x,
 			 y,
@@ -1392,7 +1443,7 @@ create_title(char *name, double x, double y,
     int gap = 8;
 
     goo_canvas_item_get_bounds (item, &bounds);
-    goo_canvas_rect_new (shape_root_item,
+    goo_canvas_rect_new (parent,
 			 x - (bounds.x2 - bounds.x1)/2 - gap,
 			 y - (bounds.y2 - bounds.y1)/2 - gap,
 			 bounds.x2 - bounds.x1 + gap*2,
@@ -1498,6 +1549,8 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, GList **
      ((g_strcasecmp((const char *)xmlnode->name,"Shape")!=0) &&
       /* or if the name is not "Title" */
       (g_strcasecmp((const char *)xmlnode->name,"Title")!=0) &&
+      /* or if the name is not "Title" */
+      (g_strcasecmp((const char *)xmlnode->name,"Info")!=0) &&
       /* or if the name is not "Option" */
       (g_strcasecmp((const char *)xmlnode->name,"Option")!=0) )
      )
@@ -1634,7 +1687,22 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, GList **
       if(name != NULL) {
 	newname = g_strcompress(name);
 
-	create_title(newname, x, y, anchor_gtk,
+	create_title(title_root_item,
+		     newname, x, y, anchor_gtk,
+		     color_rgba, color_background);
+	g_free(newname);
+      }
+    }
+  else if (g_strcasecmp((char *)xmlnode->name, "Info")==0)
+    {
+      /* Read \n is needed */
+      gchar *newname;
+
+      if(name != NULL) {
+	newname = g_strcompress(name);
+
+	create_title(info_root_item,
+		     newname, x, y, anchor_gtk,
 		     color_rgba, color_background);
 	g_free(newname);
       }
