@@ -224,7 +224,7 @@ static void menu_start (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=1;
 
       /* Set back the bar to it's original location */
-      gc_bar_set(GC_BAR_CONFIG|GC_BAR_ABOUT);
+      gc_bar_set(GC_BAR_CONFIG|GC_BAR_ABOUT|GC_BAR_JOURNAL|GC_BAR_SHARE);
 
       menuitems = g_new(MenuItems, 1);
 
@@ -262,6 +262,22 @@ static void menu_start (GcomprisBoard *agcomprisBoard)
       else
 	display_welcome(menuitems);
 
+      {
+	gchar *text = g_strdup_printf(_("Number of activities: %d"),
+				      gc_board_get_number_of_activity());
+	goo_canvas_text_new (boardRootItem,
+			     text,
+			     BOARDWIDTH - 10,
+			     BOARDHEIGHT - 10,
+			   -1,
+			   GTK_ANCHOR_EAST,
+			   "font", gc_skin_font_board_tiny,
+			   "fill-color-rgba", gc_skin_get_color("menu/text"),
+			   "alignment", PANGO_ALIGN_RIGHT,
+			   NULL);
+	g_free(text);
+      }
+
       menu_pause(FALSE);
 
     }
@@ -281,6 +297,7 @@ create_panel(GooCanvasItem *parent)
   gdouble x, y;
   gint int_y;
   GcomprisProperties *properties = gc_prop_get();
+  g_assert(properties);
 
   /* In normal mode, we show all the sections in panel */
   /* in direct submenu access, we show the icon of the submenu */
@@ -457,19 +474,9 @@ static void menu_create_item(GooCanvasItem *parent, MenuItems *menuitems, Gcompr
   GdkPixbuf *menu_pixmap = NULL;
   GooCanvasItem *menu_button;
   int difficulty;
-  gchar *tmp_board_dir;
   gdouble ratio, pixmap_w, pixmap_h;
 
-  /*
-   * Take care to load the board->icon_name from the dir specified
-   * in the board->board_dir
-   * To make it simple and reuse the gc_pixmap_load, we overwrite temporarily
-   * the gcomprisBoard->board_dir and board->board_dir
-   */
-  tmp_board_dir = gcomprisBoard->board_dir;
-  gcomprisBoard->board_dir = board->board_dir;
   menu_pixmap = gc_pixmap_load(board->icon_name);
-  gcomprisBoard->board_dir = tmp_board_dir;
 
   ratio = get_ratio (menu_pixmap, icon_size);
 
@@ -869,8 +876,8 @@ display_welcome_event (GooCanvasItem  *item,
 static void
 display_welcome (MenuItems *menuitems)
 {
-  GdkPixbuf *pixmap;
   GooCanvasItem *item;
+  RsvgHandle  *svg_handle;
 
   if (actualSectionItem)
     g_error("actualSectionItem exists in display_section !");
@@ -879,17 +886,15 @@ display_welcome (MenuItems *menuitems)
   actualSectionItem = goo_canvas_group_new(boardRootItem,
 					   NULL);
 
-  pixmap = gc_skin_pixmap_load("gcompris-about.png");
+  svg_handle = gc_skin_rsvg_get();
+  item = goo_canvas_svg_new (actualSectionItem,
+			     svg_handle,
+			     "svg-id", "#LOGO",
+			     NULL);
+  SET_ITEM_LOCATION_CENTER(item,
+			   display_x + display_w/2.0,
+			   display_y + display_h/3.0)
 
-  item = goo_canvas_image_new (actualSectionItem,
-			       pixmap,
-			       display_x + display_w/2.0 -
-			       gdk_pixbuf_get_width(pixmap)/2,
-			       display_y + display_h/2.0 -
-			       gdk_pixbuf_get_height(pixmap)/2,
-			       NULL);
-
-  gdk_pixbuf_unref(pixmap);
 
   g_signal_connect (item, "enter_notify_event",
 		    (GtkSignalFunc) display_welcome_event, menuitems);
