@@ -33,6 +33,8 @@ static void		 pause_board (gboolean pause);
 static void		 end_board (void);
 static gboolean		 is_our_board (GcomprisBoard *gcomprisBoard);
 static void		 set_level (guint level);
+static gint		 key_press(guint keyval, gchar *commit_str,
+				   gchar *preedit_str);
 
 static int gamewon;
 
@@ -70,7 +72,7 @@ static void click_on_letter_destroy_all_items(void);
 static void click_on_letter_next_level(void);
 static gint item_event(GooCanvasItem *item, GooCanvasItem *target,
 		       GdkEvent *event, gpointer data);
-static gboolean sounds_are_fine();
+static guint sounds_are_fine();
 
 static int right_position;
 static int number_of_letters=MAX_NUMBER_OF_LETTERS;
@@ -98,7 +100,7 @@ static BoardPlugin menu_bp =
     pause_board,
     end_board,
     is_our_board,
-    NULL,
+    key_press,
     NULL,
     set_level,
     NULL,
@@ -189,15 +191,53 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       if(svg_handle) {
 	gc_bar_set_repeat_icon(svg_handle);
 	g_object_unref(svg_handle);
-	gc_bar_set(GC_BAR_LEVEL|GC_BAR_REPEAT_ICON);
+	gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL|GC_BAR_REPEAT_ICON);
       } else {
-	gc_bar_set(GC_BAR_LEVEL|GC_BAR_REPEAT);
+	gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL|GC_BAR_REPEAT);
       }
-      gc_bar_location(BOARDWIDTH-270, 5, 0.7);
+      gc_bar_location(BOARDWIDTH-300, 5, 0.7);
 
     }
 
 }
+
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str) {
+  gint length_passed, i;
+
+  if(!gcomprisBoard)
+    return FALSE;
+
+  /* i suppose even numbers are passed through IM_context */
+  if ((commit_str == NULL) && (preedit_str == NULL))
+    return FALSE;
+
+  gchar *string_passed;
+  if (commit_str)
+    string_passed = commit_str;
+  else
+    string_passed = preedit_str;
+
+  length_passed = g_utf8_strlen(string_passed, -1);
+
+  for (i=0; i < length_passed; i++){
+    gunichar ckey = \
+      g_unichar_tolower( g_utf8_get_char (string_passed) );
+    gunichar cright = \
+      g_unichar_tolower( g_utf8_get_char (right_letter) );
+
+    if (ckey == cright){
+      gamewon = TRUE;
+      process_ok();
+      gc_im_reset();
+      return TRUE;
+    }
+
+    string_passed = g_utf8_next_char (string_passed);
+  }
+
+  return TRUE;
+}
+
 /* ======================================= */
 static void end_board ()
 {
@@ -260,7 +300,7 @@ static void repeat ()
     }
 }
 
-static gboolean sounds_are_fine()
+static guint sounds_are_fine()
 {
   char *letter_str;
   char *str2;
@@ -285,13 +325,19 @@ static gboolean sounds_are_fine()
 
   if (!str2)
     {
-      gchar *locale = NULL;
+      gchar *locale;
+      gchar **localsearch;
+
+      localsearch = g_strsplit_set(gc_locale_get(), "_", 2);
+      if(g_strv_length(localsearch) <= 1)
+	return NOT_OK; /* Should not happens */
+      locale = g_strdup(localsearch[0]);
+      g_strfreev(localsearch);
 
-      locale = g_strndup(gc_locale_get(), 2);
       gc_locale_reset();
-      gc_locale_set("en_US");
+      gc_locale_set(GC_DEFAULT_LOCALE);
 
-      str2 = gc_file_find_absolute("voices/en/alphabet/%s", letter_str);
+      str2 = gc_file_find_absolute("voices/$LOCALE/alphabet/%s", letter_str);
 
       if (!str2)
 	{
@@ -299,6 +345,8 @@ static gboolean sounds_are_fine()
 					locale, "en");
 	  gc_dialog(msg, gc_board_stop);
 	  g_free(msg);
+	  g_free(locale);
+	  g_free(letter_str);
 	  return (NOT_OK);
 	}
       else
@@ -307,12 +355,15 @@ static gboolean sounds_are_fine()
 	  gc_dialog(msg, click_on_letter_next_level);
 	  g_free(msg);
 	  g_free(str2);
+	  g_free(locale);
+	  g_free(letter_str);
 	  return(OK_NO_INIT);
 	}
     }
   else
     {
       g_free(str2);
+      g_free(letter_str);
     }
 
   return(OK);
