@@ -33,6 +33,7 @@ static gboolean item_event_ok (GooCanvasItem  *item,
 			       GooCanvasItem  *target,
 			       GdkEventButton *event,
 			       gchar *data);
+void gc_about_stop (void);
 
 /*
  * Do all the bar display and register the events
@@ -44,7 +45,6 @@ void gc_about_start ()
   gdouble x_start = 0;
   gint y = 0;
   GooCanvasItem *item;
-  gint plane_y;
 
   static gchar *content =
     N_("Author: Bruno Coudoin\n"
@@ -61,7 +61,10 @@ void gc_about_start ()
   gc_board_pause(TRUE);
 
   if(rootitem)
+  {
+    gc_about_stop();
     return;
+  }
 
   gc_bar_hide (TRUE);
 
@@ -164,7 +167,8 @@ void gc_about_start ()
       item = goo_canvas_image_new (rootitem,
 				   pixmap,
 				   (gdouble) (BOARDWIDTH*0.75) - gdk_pixbuf_get_width(pixmap)/2,
-				   (gdouble) y_start - gdk_pixbuf_get_height(pixmap) + 15);
+				   (gdouble) y_start - gdk_pixbuf_get_height(pixmap) + 15,
+                   NULL);
 
       gdk_pixbuf_unref(pixmap);
       g_free(sponsor_image);
@@ -172,12 +176,16 @@ void gc_about_start ()
   else
     {
       // Default sponsor is the FSF
-      pixmap = gc_skin_pixmap_load("fsflogo.png");
-      item = goo_canvas_image_new (rootitem,
-				   pixmap,
-				   (gdouble) (BOARDWIDTH*0.8) - gdk_pixbuf_get_width(pixmap)/2,
-				   (gdouble) y_start - gdk_pixbuf_get_height(pixmap)/2);
-      gdk_pixbuf_unref(pixmap);
+      RsvgHandle  *svg_handle;
+      svg_handle = gc_skin_rsvg_get();
+      item = goo_canvas_svg_new (rootitem,
+				     svg_handle,
+				     "svg-id", "#FSF_LOGO",
+				     "pointer-events", GOO_CANVAS_EVENTS_NONE,
+				     NULL);
+      goo_canvas_item_get_bounds(item, &bounds);
+      SET_ITEM_LOCATION_CENTER(item, (BOARDWIDTH*0.75),
+			       y_start + 50 - (bounds.y2 - bounds.y1) / 2);
 
       item = goo_canvas_text_new (rootitem,
 				  "Free Software Foundation\nhttp://www.fsf.org",
@@ -221,27 +229,6 @@ void gc_about_start ()
 			  (GtkSignalFunc) item_event_ok,
 			  "ok");
 
-  // The animation
-  pixmap = gc_skin_pixmap_load("gcompris-about.png");
-
-  plane_y = BOARDHEIGHT - gdk_pixbuf_get_height(pixmap);
-  item = goo_canvas_image_new (rootitem,
-			       pixmap,
-			       -1 * gdk_pixbuf_get_width(pixmap),
-			       plane_y,
-			       NULL);
-
-  goo_canvas_item_animate (item,
-			   BOARDWIDTH + gdk_pixbuf_get_width(pixmap),
-			   -1 * gdk_pixbuf_get_height(pixmap),
-			   0.4,
-			   -30,
-			   TRUE,
-			   40 * BOARDWIDTH, 40,
-			   GOO_CANVAS_ANIMATE_RESTART);
-
-  gdk_pixbuf_unref(pixmap);
-
   is_displayed = TRUE;
 
 }
