@@ -216,8 +216,8 @@ bar_start (GooCanvas *theCanvas)
   // LEVEL (Multiple buttons for this one)
   GooCanvasItem *rootitem_level = goo_canvas_group_new (rootitem, NULL);
   g_object_set (rootitem_level,
-                "visibility", GOO_CANVAS_ITEM_INVISIBLE,
-                NULL);
+		"visibility", GOO_CANVAS_ITEM_VISIBLE,
+		NULL);
   g_object_set_data (G_OBJECT(rootitem_level), "flag",
 		     GUINT_TO_POINTER(GC_BAR_LEVEL));
   buttons = g_slist_append(buttons, rootitem_level);
@@ -228,30 +228,34 @@ bar_start (GooCanvas *theCanvas)
 				   "#LEVEL_DOWN");
 
   g_object_set (item,
-                "visibility", GOO_CANVAS_ITEM_VISIBLE,
-                NULL);
+		"visibility", (properties->disable_level ?
+			       GOO_CANVAS_ITEM_INVISIBLE :
+			       GOO_CANVAS_ITEM_VISIBLE),
+		NULL);
 
   item = new_button(rootitem_level,
 		    svg_handle,
-                    GC_BAR_LEVEL,
-                    "#LEVEL_UP");
+		    GC_BAR_LEVEL,
+		    "#LEVEL_UP");
   goo_canvas_item_translate(item, 50, 0);
   g_object_set (item,
-                "visibility", GOO_CANVAS_ITEM_VISIBLE,
-                NULL);
+		"visibility", (properties->disable_level ?
+			       GOO_CANVAS_ITEM_INVISIBLE :
+			       GOO_CANVAS_ITEM_VISIBLE),
+		NULL);
 
   goo_canvas_item_get_bounds(item, &bounds);
 
   level_item =
     goo_canvas_text_new (rootitem_level,
-                         "",
-                         bounds.x1 - 10,
-                         (bounds.y2 - bounds.y1) / 2 + 8,
-                         -1,
-                         GTK_ANCHOR_CENTER,
-                         "font", gc_skin_font_board_title_bold,
-                         "fill-color-rgba", gc_skin_color_text_button,
-                         NULL);
+			 "",
+			 bounds.x1 - 10,
+			 (bounds.y2 - bounds.y1) / 2 + 8,
+			 -1,
+			 GTK_ANCHOR_CENTER,
+			 "font", gc_skin_font_board_title_bold,
+			 "fill-color-rgba", gc_skin_color_text_button,
+			 NULL);
   current_level = 1;
 
   // REPEAT (Default)
@@ -444,7 +448,8 @@ static void
 bar_hide (gboolean hide)
 {
   /* Non yet initialized : Something Wrong */
-  g_assert(rootitem);
+  if ( ! rootitem )
+    return;
 
   _hidden = hide;
 
@@ -516,6 +521,9 @@ static gchar *bar_flags_to_name(GComprisBarFlags flag)
     case GC_BAR_HELP:
       result = "help";
       break;
+    default:
+      result = NULL;
+      break;
     }
   return result;
 }
@@ -528,12 +536,17 @@ static gint bar_play_sound (GooCanvasItem *item)
 {
   int policy = gc_sound_policy_get();
   gchar *str;
-  gc_sound_policy_set(PLAY_ONLY_IF_IDLE);
 
   GComprisBarFlags flag =
     GPOINTER_TO_UINT(g_object_get_data(G_OBJECT (item), "flag"));
-  str = g_strdup_printf("voices/$LOCALE/misc/%s.ogg",
-			bar_flags_to_name(flag));
+
+  gchar *button_name = bar_flags_to_name(flag);
+  if (button_name == NULL)
+    return (FALSE);
+
+  gc_sound_policy_set(PLAY_ONLY_IF_IDLE);
+
+  str = g_strdup_printf("voices/$LOCALE/misc/%s.ogg", button_name);
 
   gc_sound_play_ogg(str, NULL);
 
