@@ -162,7 +162,10 @@ gc_config_start ()
   gc_board_pause(TRUE);
 
   if(rootitem)
+  {
+    gc_config_stop();
     return;
+  }
 
   gc_bar_hide(TRUE);
 
@@ -240,7 +243,6 @@ gc_config_start ()
   item = goo_canvas_svg_new (rootitem,
 			     gc_skin_rsvg_get(),
 			     "svg-id", (properties->fullscreen ? pixmap_checked : pixmap_unchecked),
-			     "autocrop", TRUE,
 			     NULL);
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
@@ -266,7 +268,6 @@ gc_config_start ()
   item = goo_canvas_svg_new (rootitem,
 			     gc_skin_rsvg_get(),
 			     "svg-id", (properties->music ? pixmap_checked : pixmap_unchecked),
-			     "autocrop", TRUE,
 			     NULL);
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
@@ -292,7 +293,6 @@ gc_config_start ()
   item = goo_canvas_svg_new (rootitem,
 			     gc_skin_rsvg_get(),
 			     "svg-id", (properties->fx ? pixmap_checked : pixmap_unchecked),
-			     "autocrop", TRUE,
 			     NULL);
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
@@ -318,7 +318,6 @@ gc_config_start ()
   item = goo_canvas_svg_new (rootitem,
 			     gc_skin_rsvg_get(),
 			     "svg-id", (properties->zoom ? pixmap_checked : pixmap_unchecked),
-			     "autocrop", TRUE,
 			     NULL);
   SET_ITEM_LOCATION(item, x_start, y_start - pixmap_width/2);
 
