@@ -30,6 +30,7 @@
 #include <libxml/parserInternals.h>
 
 #include "gcompris.h"
+#include "sugar_gc.h"
 
 #ifdef WIN32
 #define realpath(N,R) _fullpath((R),(N),_MAX_PATH)
@@ -123,6 +124,8 @@ GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
   pixmapfile = g_strdup_vprintf (format, args);
   va_end (args);
 
+  pixmapfile = sugar_get_journal_file(pixmapfile);
+
   /* Search */
   filename = gc_file_find_absolute(pixmapfile);
 
@@ -568,7 +571,7 @@ gc_file_find_absolute(const gchar *format, ...)
   int			 i = 0;
   gchar			*filename;
   gchar			*absolute_filename;
-  gchar			*dir_to_search[4];
+  gchar			*dir_to_search[6];
   GcomprisProperties	*properties = gc_prop_get();
 
   if (!format)
@@ -591,6 +594,8 @@ gc_file_find_absolute(const gchar *format, ...)
   dir_to_search[i++] = properties->user_dir;
   dir_to_search[i++] = properties->package_data_dir;
   dir_to_search[i++] = properties->package_skin_dir;
+  if(properties->package_extra_data_dir)
+    dir_to_search[i++] = properties->package_extra_data_dir;
   dir_to_search[i++] = NULL;
 
   absolute_filename = g_strdup(filename);
@@ -598,34 +603,48 @@ gc_file_find_absolute(const gchar *format, ...)
 
   while (dir_to_search[i])
     {
-      gchar **tmp;
+      gchar **filesplit;
+      gchar **locale;
+      gchar *filename2;
       g_free(absolute_filename);
 
-      /* Check there is a $LOCALE to replace */
-      if((tmp = g_strsplit(filename, "$LOCALE", -1)))
+      /* Maybe there is a $LOCALE to replace */
+      filesplit = g_strsplit(filename, "$LOCALE", -1);
+      if(g_strv_length(filesplit) == 1)
+	{
+	  g_strfreev(filesplit);
+	  absolute_filename = \
+	    g_strdup_printf("%s/%s", dir_to_search[i], filename);
+	  if(g_file_test (absolute_filename, G_FILE_TEST_EXISTS))
+	    goto FOUND;
+	}
+      else
 	{
-	  gchar locale[6];
-	  gchar *filename2;
-
 	  /* First try with the long locale */
-	  g_strlcpy(locale, gc_locale_get(), sizeof(locale));
-	  filename2 = g_strjoinv(locale, tmp);
-	  absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i], filename2);
+	  locale = g_strsplit_set(gc_locale_get(), ".", 2);
+	  filename2 = g_strjoinv(locale[0], filesplit);
+	  absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i],
+					      filename2);
+	  g_strfreev(locale);
 	  if(g_file_test (absolute_filename, G_FILE_TEST_EXISTS))
 	    {
-	      g_strfreev(tmp);
+	      g_strfreev(filesplit);
 	      g_free(filename2);
 	      goto FOUND;
 	    }
 	  g_free(filename2);
 	  /* Try the short locale */
-	  if(g_strv_length(tmp)>1)
+	  if(g_strv_length(filesplit)>1)
 	    {
-	      locale[2] = '\0';
-	      filename2 = g_strjoinv(locale, tmp);
-	      g_strfreev(tmp);
+	      locale = g_strsplit_set(gc_locale_get(), "_", 2);
+	      if(g_strv_length(locale) < 1)
+		goto NOT_FOUND;
+	      filename2 = g_strjoinv(locale[0], filesplit);
+	      g_strfreev(locale);
+	      g_strfreev(filesplit);
 	      g_free(absolute_filename);
-	      absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i], filename2);
+	      absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i],
+						  filename2);
 	      if(g_file_test (absolute_filename, G_FILE_TEST_EXISTS))
 		{
 		  g_free(filename2);
@@ -635,19 +654,13 @@ gc_file_find_absolute(const gchar *format, ...)
 
 	    }
 	  else
-	    g_strfreev(tmp);
-	}
-      else
-	{
-	  absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i], filename);
-
-	  if(g_file_test (absolute_filename, G_FILE_TEST_EXISTS))
-	    goto FOUND;
+	    g_strfreev(filesplit);
 	}
 
       i++;
     }
 
+ NOT_FOUND:
   g_free(filename);
   g_free(absolute_filename);
   return NULL;
@@ -803,7 +816,6 @@ gc_util_button_text_svg(GooCanvasItem *rootitem,
   item = goo_canvas_svg_new (rootitem,
 			     gc_skin_rsvg_get(),
 			     "svg-id", button_id,
-			     "autocrop", TRUE,
 			     NULL);
   SET_ITEM_LOCATION_CENTER(item, x, y);
 
