@@ -47,6 +47,7 @@
 #include "gcompris_config.h"
 #include "about.h"
 #include "bar.h"
+#include "sugar_gc.h"
 #include "status.h"
 #include <locale.h>
 
@@ -70,8 +71,6 @@ gchar * exec_prefix = NULL;
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
 static void map_cb  (GtkWidget *widget, gpointer data);
-static gboolean _realize_callback (GtkWidget *widget, GdkEventExpose *event,
-				   gpointer data);
 static gint board_widget_key_press_callback (GtkWidget   *widget,
 					    GdkEventKey *event,
 					    gpointer     client_data);
@@ -117,13 +116,16 @@ static gint popt_fullscreen	   = FALSE;
 static gint popt_window		   = FALSE;
 static gint popt_sound		   = FALSE;
 static gint popt_mute		   = FALSE;
+static gint popt_mute_music    = FALSE;
 static gint popt_cursor		   = FALSE;
+static gint popt_nocursor	   = FALSE;
 static gint popt_version	   = FALSE;
 static gint popt_difficulty_filter = FALSE;
 static gint popt_debug		   = FALSE;
 static gint popt_nolockcheck	   = FALSE;
 static gchar *popt_root_menu       = NULL;
 static gchar *popt_package_data_dir = NULL;
+static gchar *popt_package_extra_data_dir = NULL;
 static gchar *popt_package_skin_dir = NULL;
 static gchar *popt_plugin_dir      = NULL;
 static gchar *popt_python_plugin_dir = NULL;
@@ -140,13 +142,11 @@ static gchar *popt_user_dir	   = NULL;
 static gint  popt_experimental     = FALSE;
 static gint  popt_no_quit	   = FALSE;
 static gint  popt_no_config        = FALSE;
+static gint  popt_no_level         = FALSE;
 static gchar *popt_server          = NULL;
 static gint  *popt_web_only        = NULL;
 static gchar *popt_cache_dir       = NULL;
 static gchar *popt_drag_mode       = NULL;
-static gchar *sugarBundleId        = NULL;
-static gchar *sugarActivityId      = NULL;
-static gint popt_sugar_look        = FALSE;
 static gint popt_no_zoom           = FALSE;
 static gdouble popt_timing_base    = 1.0;
 static gdouble popt_timing_mult    = 1.0;
@@ -164,8 +164,14 @@ static GOptionEntry options[] = {
   {"mute", 'm', 0, G_OPTION_ARG_NONE, &popt_mute,
    N_("run GCompris without sound."), NULL},
 
+  {"mute_music", '\0', 0, G_OPTION_ARG_NONE, &popt_mute_music,
+   N_("run GCompris without music."), NULL},
+
   {"cursor", 'c', 0, G_OPTION_ARG_NONE, &popt_cursor,
-   N_("run GCompris with the default gnome cursor."), NULL},
+   N_("run GCompris with the default system cursor."), NULL},
+
+  {"nocursor", 'C', 0, G_OPTION_ARG_NONE, &popt_nocursor,
+   N_("run GCompris without cursor (touch screen mode)."), NULL},
 
   {"difficulty", 'd', 0, G_OPTION_ARG_INT, &popt_difficulty_filter,
    N_("display only activities with this difficulty level."), NULL},
@@ -184,6 +190,9 @@ static GOptionEntry options[] = {
   {"package_data_dir", 'A', 0, G_OPTION_ARG_STRING, &popt_package_data_dir,
    N_("GCompris will find the data dir in this directory"), NULL},
 
+  {"package_extra_data_dir", 0, 0, G_OPTION_ARG_STRING, &popt_package_extra_data_dir,
+   N_("GCompris will find the extra data dir in this directory"), NULL},
+
   {"package_skin_dir", 'S', 0, G_OPTION_ARG_STRING, &popt_package_skin_dir,
    N_("GCompris will find the skins in this directory"), NULL},
 
@@ -232,6 +241,9 @@ static GOptionEntry options[] = {
   {"disable-config",'\0', 0, G_OPTION_ARG_NONE, &popt_no_config,
    N_("Disable the config button"), NULL},
 
+  {"disable-level",'\0', 0, G_OPTION_ARG_NONE, &popt_no_level,
+   N_("Disable the level button"), NULL},
+
   {"server", '\0', 0, G_OPTION_ARG_STRING, &popt_server,
    N_("GCompris will get images, sounds and activity data from this server if not found locally."), NULL},
 
@@ -248,15 +260,6 @@ static GOptionEntry options[] = {
   {"nolockcheck", '\0', 0, G_OPTION_ARG_NONE, &popt_nolockcheck,
    N_("Do not avoid the execution of multiple instances of GCompris."), NULL},
 
-  {"sugarBundleId", '\0', 0, G_OPTION_ARG_STRING, &sugarBundleId,
-   "Sugar Bundle Id", NULL},
-
-  {"sugarActivityId", '\0', 0, G_OPTION_ARG_STRING, &sugarActivityId,
-   "Sugar Activity Id", NULL},
-
-  {"sugar",'\0', 0, G_OPTION_ARG_NONE, &popt_sugar_look,
-   ("Use Sugar DE look&feel"), NULL},
-
   {"no-zoom",'\0', 0, G_OPTION_ARG_NONE, &popt_no_zoom,
    ("Disable maximization zoom"), NULL},
 
@@ -458,10 +461,31 @@ guint gc_cursor_get()
   return gc_cursor_current;
 }
 
+/* Set the cursor to be invisible
+ * (Useful for touch screens)
+ */
+void gc_cursor_hide()
+{
+  char in_cursor[] = {0x0};
+  GdkCursor *cursor;
+  GdkBitmap *bp;
+  GdkColor color = {0, 0, 0, 0};
+
+  bp = gdk_bitmap_create_from_data(NULL , in_cursor , 1, 1);
+  cursor = gdk_cursor_new_from_pixmap(bp , bp ,
+				      &color , &color ,
+				      1 , 1);
+  gdk_window_set_cursor(window->window , cursor);
+  gdk_cursor_unref(cursor);
+}
+
 void gc_cursor_set(guint gdk_cursor_type)
 {
   GdkCursor *cursor = NULL;
 
+  if (properties->nocursor)
+    return;
+
   // Little hack to force gcompris to use the default cursor
   if(gdk_cursor_type==GCOMPRIS_DEFAULT_CURSOR)
     gdk_cursor_type=properties->defaultcursor;
@@ -476,31 +500,31 @@ void gc_cursor_set(guint gdk_cursor_type)
 
     switch (gdk_cursor_type) {
     case GCOMPRIS_DEFAULT_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/default.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/default.png");
       break;
     case GCOMPRIS_LINE_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/line.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/line.png");
       break;
     case GCOMPRIS_RECT_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/rect.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/rect.png");
       break;
     case GCOMPRIS_FILLRECT_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/fillrect.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/fillrect.png");
       break;
     case GCOMPRIS_CIRCLE_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/circle.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/circle.png");
       break;
     case GCOMPRIS_FILLCIRCLE_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/fillcircle.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/fillcircle.png");
       break;
     case GCOMPRIS_FILL_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/fill.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/fill.png");
       break;
     case GCOMPRIS_DEL_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/del.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/del.png");
       break;
     case GCOMPRIS_SELECT_CURSOR :
-      cursor_pixbuf = gc_skin_pixmap_load("cursors/select.png");
+      cursor_pixbuf = gc_skin_pixmap_load_or_null("cursors/select.png");
       break;
     default :
       return;
@@ -515,6 +539,13 @@ void gc_cursor_set(guint gdk_cursor_type)
 	gdk_cursor_unref(cursor);
 	gdk_pixbuf_unref(cursor_pixbuf);
       }
+    else
+      {
+	/* The cursor image was not found, falback to default one */
+	properties->defaultcursor = GDK_LEFT_PTR;
+	gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
+	return;
+      }
   }
   gc_cursor_current = gdk_cursor_type;
 }
@@ -647,34 +678,6 @@ gc_set_default_background(GooCanvasItem *parent)
 			  "#BACKGROUND");
 }
 
-static gboolean
-_realize_callback (GtkWidget *widget, GdkEventExpose *event, gpointer data)
-{
-#ifdef USE_SUGAR
-  Window xwindow = GDK_WINDOW_XWINDOW(window->window);
-  /*
-   * Sugar requires properties to be set before the windows is realized
-   */
-  if (sugarBundleId)
-    XChangeProperty(GDK_DISPLAY(),
-		    xwindow,
-		    XInternAtom(GDK_DISPLAY(), "_SUGAR_BUNDLE_ID", 0),
-		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
-		    PropModeReplace,
-		    (unsigned char *) sugarBundleId, strlen(sugarBundleId));
-
-  if (sugarActivityId)
-    XChangeProperty(GDK_DISPLAY(),
-		    xwindow,
-		    XInternAtom(GDK_DISPLAY(), "_SUGAR_ACTIVITY_ID", 0),
-		    XInternAtom(GDK_DISPLAY(), "STRING", 0), 8,
-		    PropModeReplace,
-		    (unsigned char *) sugarActivityId, strlen(sugarActivityId));
-#endif
-
-  return FALSE;
-}
-
 static void
 init_workspace()
 {
@@ -796,8 +799,6 @@ static void setup_window ()
 
   gtk_window_set_default_size(GTK_WINDOW(window), BOARDWIDTH, BOARDHEIGHT);
   gtk_window_set_wmclass(GTK_WINDOW(window), "gcompris", "GCompris");
-  g_signal_connect (GTK_OBJECT (window), "realize",
-		    G_CALLBACK (_realize_callback), NULL);
   gtk_widget_realize (window);
 
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
@@ -807,7 +808,10 @@ static void setup_window ()
 		      GTK_SIGNAL_FUNC (map_cb), NULL);
 
   // Set the cursor
-  gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
+  if (properties->nocursor)
+    gc_cursor_hide();
+  else
+    gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
 
   canvas     = goo_canvas_new();
 
@@ -1043,7 +1047,7 @@ void _set_geometry_hints(gboolean state)
   gint geom_mask = GDK_HINT_RESIZE_INC |
                    GDK_HINT_MIN_SIZE |
                    GDK_HINT_BASE_SIZE;
-  if (!popt_sugar_look)
+  if (!sugar_detected())
       geom_mask |= GDK_HINT_ASPECT;
   gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, &hints, geom_mask);
 }
@@ -1078,7 +1082,7 @@ void gc_fullscreen_set(gboolean state)
       gtk_window_set_decorated ( GTK_WINDOW ( window ), FALSE );
       gtk_window_set_type_hint ( GTK_WINDOW ( window ),
 				 GDK_WINDOW_TYPE_HINT_DESKTOP );
-      if (popt_sugar_look)
+      if (sugar_detected())
 	gtk_window_maximize ( GTK_WINDOW( window ) );
       else
         gtk_window_fullscreen ( GTK_WINDOW ( window ) );
@@ -1133,6 +1137,7 @@ static void cleanup()
   single_instance_release(); /* Must be done before property destroy */
   gc_board_stop();
   gc_db_exit();
+  sugar_cleanup();
   gc_fullscreen_set(FALSE);
   gc_menu_destroy();
   gc_net_destroy();
@@ -1153,6 +1158,7 @@ static void quit_cb (GtkWidget *widget, gpointer data)
 #endif
   cleanup();
   gtk_main_quit();
+  gc_sound_close();
 
   /*
    * Very important or GCompris crashes on exit when closed from the dialog
@@ -1172,21 +1178,41 @@ static void map_cb (GtkWidget *widget, gpointer data)
       is_mapped = TRUE;
       GcomprisBoard *board_to_start;
 
+      if (! gc_skin_load(properties->skin) )
+	{
+	  gc_status_init("");
+	  gchar *filename = \
+	    g_strdup_printf("%s/%s/skin.xml",
+			    properties->package_skin_dir,
+			    properties->skin);
+
+	  gc_status_set_msg(_("Failed to load the skin '%s'"
+			      " (Check the file exists and is readable)"),
+			    filename);
+	  g_free(filename);
+	  return;
+	}
+
       gc_set_default_background (goo_canvas_get_root_item (GOO_CANVAS(canvas)));
 
       gc_fullscreen_set(properties->fullscreen);
 
-      gc_status_init("");
+      gc_bar_start(GTK_CONTAINER(workspace), GOO_CANVAS(canvas));
+
       gc_board_init();
+
+      if (sugar_delayed_start())
+        gc_status_init(_("Retrieving remote data..."));
+      else
+      {
+      gc_status_init("");
       /* Load all the menu once */
       gc_menu_load();
       /* Save the root_menu */
       properties->menu_board = gc_menu_section_get(properties->root_menu);
-
-      gc_bar_start(GTK_CONTAINER(workspace), GOO_CANVAS(canvas));
-
       gc_status_close();
 
+
       board_to_start = get_board_to_start();
 
       if(!board_to_start) {
@@ -1204,6 +1230,8 @@ static void map_cb (GtkWidget *widget, gpointer data)
       }
 
     }
+  }
+
   g_message("gcompris window is now mapped");
 }
 
@@ -1260,11 +1288,13 @@ static void load_properties ()
 
   /* Display the directory value we have */
   printf("package_data_dir         = %s\n", properties->package_data_dir);
+  printf("package_extra_data_dir   = %s\n", properties->package_extra_data_dir);
   printf("package_skin_dir         = %s\n", properties->package_skin_dir);
   printf("package_menu_dir         = %s\n", properties->menu_dir);
   printf("package_locale_dir       = %s\n", properties->package_locale_dir);
   printf("package_plugin_dir       = %s\n", properties->package_plugin_dir);
   printf("package_python_plugin_dir= %s\n", properties->package_python_plugin_dir);
+  printf("user_dir                 = %s\n", properties->user_dir);
 }
 
 GcomprisProperties *gc_prop_get ()
@@ -1389,6 +1419,7 @@ gc_update_canvas_zoom()
 static void
 start_bg_music (gchar *file)
 {
+  properties->music_paused = FALSE;
   g_message ("start_bg_music %s", file);
   gc_sound_bg_reopen();
 }
@@ -1477,6 +1508,8 @@ main (int argc, char *argv[])
 
   gtk_init (&argc, &argv);
 
+  sugar_setup(&argc, &argv);
+
   /* Argument parsing */
   context = g_option_context_new("GCompris");
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
@@ -1484,14 +1517,15 @@ main (int argc, char *argv[])
   g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free(context);
 
-  // Set the default gcompris cursor
-  properties->defaultcursor = GCOMPRIS_DEFAULT_CURSOR;
-
   /* Set the default message handler, it avoids message with option -D */
   g_log_set_handler (NULL, G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_WARNING | G_LOG_LEVEL_DEBUG | G_LOG_FLAG_FATAL
 		     | G_LOG_FLAG_RECURSION, gc_log_handler, NULL);
 
   /*------------------------------------------------------------*/
+
+  if (sugar_jobject_root_menu())
+    popt_root_menu = (gchar*)sugar_jobject_root_menu();
+
   if (popt_debug)
     {
       gc_debug = TRUE;
@@ -1572,12 +1606,25 @@ main (int argc, char *argv[])
       properties->fx = TRUE;
     }
 
+  if (popt_mute_music)
+    {
+      g_message("Music disabled");
+      properties->music = FALSE;
+    }
+
+
   if (popt_cursor)
     {
-      g_message("Default gnome cursor enabled");
+      g_message("Default system cursor enabled");
       properties->defaultcursor = GDK_LEFT_PTR;
     }
 
+  if (popt_nocursor)
+    {
+      g_message("No cursors");
+      properties->nocursor = TRUE;
+    }
+
   if (popt_experimental)
     {
       g_message("Experimental boards allowed");
@@ -1596,6 +1643,12 @@ main (int argc, char *argv[])
       properties->disable_config = TRUE;
     }
 
+  if (popt_no_level)
+    {
+      g_message("Disable level button");
+      properties->disable_level = TRUE;
+    }
+
   if (popt_difficulty_filter>=0)
     {
       /* This option provide less capacity than the GUI since we cannot set the filter_style */
@@ -1610,6 +1663,12 @@ main (int argc, char *argv[])
     properties->package_data_dir = g_strdup(popt_package_data_dir);
   }
 
+  if (popt_package_extra_data_dir) {
+    printf("Overloaded package_extra_data_dir  = %s\n", popt_package_extra_data_dir);
+    g_free(properties->package_extra_data_dir);
+    properties->package_extra_data_dir = g_strdup(popt_package_extra_data_dir);
+  }
+
   if (popt_package_skin_dir) {
     printf("Overloaded package_skin_dir          = %s\n", popt_package_skin_dir);
     g_free(properties->package_skin_dir);
@@ -1759,7 +1818,8 @@ main (int argc, char *argv[])
     properties->music = FALSE;
     properties->fx = FALSE;
     g_message("Fullscreen and cursor is disabled");
-    properties->fullscreen = FALSE;
+    if (!sugar_detected())
+      properties->fullscreen = FALSE;
     properties->defaultcursor = GDK_LEFT_PTR;
   }
 
@@ -1824,6 +1884,8 @@ main (int argc, char *argv[])
     else
       gc_db_init(FALSE /* ENABLE DATABASE */);
 
+  sugar_setup_profile(popt_root_menu, popt_administration);
+
   /* An alternate profile is requested, check it does exists */
   if (popt_profile){
     properties->profile = gc_db_profile_from_name_get(popt_profile);
@@ -1855,17 +1917,6 @@ main (int argc, char *argv[])
     exit(0);
   }
 
-  if (popt_sugar_look){
-    #ifdef USE_SUGAR
-      extern Bar sugar_bar;
-      gc_bar_register(&sugar_bar);
-      extern Score sugar_score;
-      gc_score_register(&sugar_score);
-    #else
-	  printf("GCompris was not built with Sugar DE support.\n");
-      popt_sugar_look = FALSE;
-    #endif
-  }
 
   if (popt_no_zoom){
     g_message("Zoom disabled");
@@ -1880,8 +1931,6 @@ main (int argc, char *argv[])
   gc_net_init();
   gc_cache_init();
 
-  gc_skin_load(properties->skin);
-
   gc_sound_build_music_list();
 
   if(properties->music || properties->fx)
@@ -1894,6 +1943,8 @@ main (int argc, char *argv[])
 
   setup_window ();
 
+  sugar_setup_x11();
+
   gtk_widget_show_all (window);
 
 
@@ -1902,11 +1953,14 @@ main (int argc, char *argv[])
   else
     mute = TRUE;
 
+  properties->music_paused = FALSE;
+
   /* If a specific activity is selected, skeep the intro music */
   if(!popt_root_menu)
     {
       if (properties->music)
 	{
+      properties->music_paused = TRUE;
 	  gc_sound_play_ogg("music/intro.ogg",
 			    NULL);
 	  gc_sound_play_ogg_cb("voices/$LOCALE/misc/welcome.ogg",
@@ -1916,11 +1970,6 @@ main (int argc, char *argv[])
 	gc_sound_play_ogg("voices/$LOCALE/misc/welcome.ogg", NULL);
     }
 
-#ifndef WIN32
-  if (sugarActivityId)
-    gc_dbus_init(sugarActivityId);
-#endif
-
   gtk_main ();
 
   return(0);
