@@ -133,7 +133,7 @@ static sqlite3 *gcompris_db=NULL;
        UPDATE list_users_in_groups SET group_id=(SELECT wholegroup_id FROM class WHERE class_id=new.class_id) WHERE user_id=new.user_id; \
      END;"
 
-
+#ifdef USE_SQLITE
 /* Return the user version of the database
  * or -1 if failed. The user version is an sqlite
  * specific information stored in the pragma
@@ -389,6 +389,7 @@ gint _gc_boards_count()
   sqlite3_free_table(result);
   return count;
 }
+#endif // USE_SQLITE
 
 gboolean gc_db_init(gboolean disable_database_)
 {
@@ -826,8 +827,6 @@ GList *gc_menu_load_db(GList *boards_list)
 
 #ifdef USE_SQLITE
 
-  GcomprisProperties	*properties = gc_prop_get();
-
   GList *boards = boards_list;
 
   char *zErrMsg;
@@ -865,9 +864,6 @@ GList *gc_menu_load_db(GList *boards_list)
     gcomprisBoard->gmodule      = NULL;
     gcomprisBoard->gmodule_file = NULL;
 
-    /* From DB we have only package_data_dir. */
-    gcomprisBoard->board_dir = g_strdup(properties->package_data_dir);
-
     gcomprisBoard->board_id = atoi(result[i++]);
     gcomprisBoard->name = g_strdup(result[i++]);
     gcomprisBoard->section_id = atoi(result[i++]);
@@ -1248,6 +1244,14 @@ GcomprisProfile *gc_db_get_profile()
 
 GList *gc_db_users_from_group_get(gint group_id)
 {
+  GcomprisProfile *profile = gc_profile_get_current();
+
+  if (profile && profile->groups)
+  {
+    GcomprisGroup *group = g_hash_table_lookup(profile->groups, GINT_TO_POINTER(group_id));
+    return group ? group->user_ids : NULL;
+  }
+
   SUPPORT_OR_RETURN(NULL);
 
 #ifdef USE_SQLITE
@@ -1539,9 +1543,24 @@ gc_db_set_board_conf(GcomprisProfile *profile,
 #define GET_CONF(p, b)							\
   "SELECT conf_key, conf_value FROM board_profile_conf WHERE profile_id=%d AND board_id=%d;", p, b
 
+static void merge_config(gchar *key, gchar *value, GHashTable *merge_to)
+{
+  g_hash_table_replace (merge_to, g_strdup(key), g_strdup(value));
+}
+
 GHashTable *gc_db_conf_with_table_get(int profile_id, int board_id,
 				      GHashTable *table )
 {
+  GcomprisProfile *profile = gc_profile_get_current();
+  if (profile && profile_id == profile->profile_id && profile->config)
+  {
+    GHashTable *config_table = g_hash_table_lookup(profile->config,
+            GINT_TO_POINTER(board_id));
+    if (config_table)
+      g_hash_table_foreach(config_table, (GHFunc)merge_config, table);
+    return table;
+  }
+
   GHashTable *hash_conf = table;
 
   SUPPORT_OR_RETURN(hash_conf);
@@ -1595,12 +1614,9 @@ GHashTable *gc_db_conf_with_table_get(int profile_id, int board_id,
 GHashTable *gc_db_get_conf(GcomprisProfile *profile, GcomprisBoard  *board )
 {
   GHashTable *hash_result = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
-
-  SUPPORT_OR_RETURN(hash_result);
-
-#ifdef USE_SQLITE
+  if (profile == NULL)
+    return hash_result;
   return gc_db_conf_with_table_get( profile->profile_id, board->board_id, hash_result) ;
-#endif
 }
 
 GHashTable *gc_db_get_board_conf()
@@ -1763,6 +1779,11 @@ GList *gc_db_profiles_list_get()
 
 GcomprisGroup *gc_db_get_group_from_id(int group_id)
 {
+  GcomprisProfile *profile = gc_profile_get_current();
+
+  if (profile && profile->groups)
+    return g_hash_table_lookup(profile->groups, GINT_TO_POINTER(group_id));
+
   SUPPORT_OR_RETURN(NULL);
 
 #ifdef USE_SQLITE
@@ -1818,6 +1839,11 @@ GcomprisGroup *gc_db_get_group_from_id(int group_id)
 
 GList *gc_db_get_groups_list()
 {
+  GcomprisProfile *profile = gc_profile_get_current();
+
+  if (profile && profile->groups)
+    return g_hash_table_get_values(profile->groups);
+
   SUPPORT_OR_RETURN(NULL);
 
 #ifdef USE_SQLITE
@@ -1877,8 +1903,6 @@ GcomprisBoard *gc_db_get_board_from_id(int board_id)
 
 #ifdef USE_SQLITE
 
-  GcomprisProperties	*properties = gc_prop_get();
-
   char *zErrMsg;
   char **result;
   int rc;
@@ -1919,9 +1943,6 @@ GcomprisBoard *gc_db_get_board_from_id(int board_id)
   gcomprisBoard->gmodule      = NULL;
   gcomprisBoard->gmodule_file = NULL;
 
-  /* From DB we have only package_data_dir. */
-  gcomprisBoard->board_dir = g_strdup(properties->package_data_dir);
-
   gcomprisBoard->board_id = board_id;
   gcomprisBoard->name = g_strdup(result[i++]);
   gcomprisBoard->section_id = atoi(result[i++]);
