@@ -143,10 +143,13 @@ gc_prop_new ()
 {
   GcomprisProperties *tmp;
 
-  tmp = (GcomprisProperties *) malloc (sizeof (GcomprisProperties));
+  tmp = (GcomprisProperties *) calloc (1, sizeof (GcomprisProperties));
   tmp->music		 = 1;
   tmp->fx		 = 1;
   tmp->fullscreen	 = 1;
+  // Set the default gcompris cursor
+  tmp->defaultcursor	 = GCOMPRIS_DEFAULT_CURSOR;
+  tmp->nocursor		 = 0;
   tmp->timer		 = 1;
   tmp->skin		 = g_strdup("babytoy");
   tmp->key		 = g_strdup("default");
@@ -156,6 +159,7 @@ gc_prop_new ()
   tmp->difficulty_filter = 1;				/* No difficulty filter by default */
   tmp->disable_quit      = 0;				/* Used to remove the quit button from the bar. Use it for kiosk mode */
   tmp->disable_config    = 0;				/* Used to remove the config button from the bar. Use it for kiosk mode */
+  tmp->disable_level     = 0;				/* Used to remove the level button from the bar */
   tmp->display_resource  = 0;
   tmp->root_menu         = g_strdup("/");
   tmp->profile           = NULL;
@@ -170,6 +174,7 @@ gc_prop_new ()
   tmp->package_locale_dir         = NULL;
   tmp->package_plugin_dir         = NULL;
   tmp->package_python_plugin_dir  = NULL;
+  tmp->package_extra_data_dir     = NULL;
   tmp->menu_dir			  = NULL;
   tmp->system_icon_dir            = NULL;
   tmp->cache_dir                  = NULL;
@@ -177,6 +182,7 @@ gc_prop_new ()
   tmp->drag_mode                  = GC_DRAG_MODE_GRAB;
 
   tmp->zoom                       = 1;
+  tmp->music_paused               = 1;
 
   tmp->config_dir = gc_prop_default_config_directory_get();
   tmp->user_dir = gc_prop_default_user_directory_get();
@@ -399,6 +405,9 @@ gc_prop_load (GcomprisProperties *props, GCPropSourceConf source_conf)
 	} else if(!strcmp(value.v_identifier, "disable_config")) {
 	  if(!scan_get_int(scanner, &props->disable_config))
 	    g_warning("Config file parsing error on token %s", token);
+	} else if(!strcmp(value.v_identifier, "disable_level")) {
+	  if(!scan_get_int(scanner, &props->disable_level))
+	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "filter_style")) {
 	  if(!scan_get_int(scanner, &props->filter_style))
 	    g_warning("Config file parsing error on token %s", token);
@@ -522,6 +531,7 @@ gc_prop_destroy (GcomprisProperties *props)
   g_free(props->package_locale_dir);
   g_free(props->package_plugin_dir);
   g_free(props->package_python_plugin_dir);
+  g_free(props->package_extra_data_dir);
   g_free(props->menu_dir);
   g_free(props->system_icon_dir);
   g_free(props->cache_dir);
