@@ -32,12 +32,14 @@ typedef struct {
   gint		fx;
   gint		fullscreen;
   gint		defaultcursor;
+  gint		nocursor;
   gint		timer;
   gint		filter_style;
   gint		difficulty_filter;
   gint		difficulty_max;
   gint		disable_quit;
   gint		disable_config;
+  gint		disable_level;
   gint		display_resource;
   gchar        *root_menu;
   gchar        *package_data_dir;
@@ -45,6 +47,7 @@ typedef struct {
   gchar        *package_locale_dir;
   gchar        *package_plugin_dir;
   gchar        *package_python_plugin_dir;
+  gchar        *package_extra_data_dir;
   gchar        *menu_dir;
   gchar        *system_icon_dir;
   gchar        *cache_dir;
@@ -66,6 +69,7 @@ typedef struct {
   gchar        *server;
   gint		drag_mode;
   gint		zoom;
+  gint		music_paused;
 } GcomprisProperties;
 
 GcomprisProperties	*gc_prop_get (void);
