@@ -95,9 +95,14 @@ gc_sound_build_music_list()
   gchar *music_dir;
   GDir *dir;
   const gchar *one_dirent;
+  gchar *data_dir;
 
   /* Load the Music directory file names */
-  music_dir = g_strconcat(properties->package_data_dir, "/music/background",
+  if(properties->package_extra_data_dir)
+    data_dir = properties->package_extra_data_dir;
+  else
+    data_dir = properties->package_data_dir;
+  music_dir = g_strconcat(data_dir, "/music/background",
 			  NULL);
 
   dir = g_dir_open(music_dir, 0, NULL);
