@@ -1172,12 +1172,11 @@ config_start(GcomprisBoard *agcomprisBoard,
   GHashTable *config = gc_db_get_conf( profile_conf, board_conf);
 
   gchar *drag_mode_str = g_hash_table_lookup( config, "drag_mode");
-  gint drag_previous;
 
   if (drag_mode_str && (strcmp (drag_mode_str, "NULL") != 0))
-    drag_previous = (gint ) g_ascii_strtod(drag_mode_str, NULL);
+    drag_mode = (gint ) g_ascii_strtod(drag_mode_str, NULL);
   else
-    drag_previous = 0;
+    drag_mode = 0;
 
   gc_board_config_combo_drag(bconf, drag_mode);
 
